import re
import sys

from mastodon_toot_follower.app import App
from mastodon_toot_follower.conversation import Conversation


def main():
    if len(sys.argv) != 2:
        usage()
    toot_url = sys.argv[1]

    #
    # PARSE TOOT URL
    #

    # Example: https://mastodon.instance/@user@another.instance/123456
    pattern = re.compile(r'(^https://[^/]+)/([^/]+)/([0-9]+)$')
    match = pattern.match(toot_url)
    if match is None:
        print(f'Could not parse toot url: {toot_url}', file=sys.stderr)
        usage()
    instance_url, username, toot_id = match.group(1), match.group(2), match.group(3)

    #
    # RUN THE APP
    #

    app = App()
    conversation = Conversation(app=app,
                                mastodon_instance=instance_url,
                                toot_id=toot_id)
    print(f'Conversation length: {conversation.get_conversation_length()}')
    print(f'Updates: {conversation.get_changed_toots_and_update()}')


def usage():
    print(f'\n'
          f'usage: {sys.argv[0]} MASTODON_TOOT_URL\n'
          f'example: {sys.argv[0]} https://mastodon.instance/@user@another.instance/123456', file=sys.stderr)
    exit(1)


if __name__ == '__main__':
    main()
